"""
This function Reads the output of the Ayromlou 2021 version of L-Galaxies
See https://lgalaxiespublicrelease.github.io/ for more info
Written by M. Ayromlou (ayromlou@mpa-garching.mpg.de -- ayromlou@gmail.com)
"""

import numpy as np
import h5py as h5py

def Read_LGalaxies(Catalog_Type,Outputdir,SnapNum):
    GroupName = 'Galaxy'
    
    filter_list = []
    
    if Catalog_Type == 'Main':
        f = h5py.File('%s/LGal_Ayromlou2021_snap%d.hdf5' %(Outputdir,SnapNum),'r')
        from LGalaxies_snap_struct_A2021 import LGalaxiesStruct
        from LGalaxies_snap_struct_A2021 import PropertiesToRead
        galtype = f['%s/%s' %(GroupName,'Type')][()]
        n_gals_A20_MR = np.size(galtype)
    elif Catalog_Type == 'Additional':
        f = h5py.File('%s/LGal_Ayromlou2021_extra_snap%d.hdf5' %(Outputdir,SnapNum),'r')
        from LGalaxies_snap_struct_extra_A2021 import LGalaxiesStruct
        from LGalaxies_snap_struct_extra_A2021 import PropertiesToRead
        gal_redshift = f['%s/%s' %(GroupName,'Redshift')][()]
        n_gals_A20_MR = np.size(gal_redshift)
    
    template = LGalaxiesStruct
    props = PropertiesToRead
    for prop in props:
        if props[prop]:
            filter_list.append((prop,template[prop]))
    filter_dtype = np.dtype(filter_list)  
    
    
    LGal = np.zeros(n_gals_A20_MR,dtype=filter_dtype) # All the simulation subhalos
    
    for prop in props:
        if props[prop]:
            LGal[prop] = f['%s/%s' %(GroupName,prop)][()] 
        
    f.close()

    return LGal