"""
This Structure file contains the structure of the "Additional" catalogue of the Ayromlou 2021 version of L-Galaxies.
See https://lgalaxiespublicrelease.github.io/ for more info
Written by M. Ayromlou (ayromlou@mpa-garching.mpg.de -- ayromlou@gmail.com)
"""
import numpy as np

LGalaxiesStruct = np.dtype([
('Type',np.int32,1),
('HaloIndex',np.int32,1),
('SnapNum',np.int32,1),
('LookBackTimeToSnap',np.float32,1),
('Central_M_Crit200',np.float32,1),
('Central_R_Crit200',np.float32,1),
('DistanceToCentralGal',np.float32,3),
('Pos',np.float32,3),
('Vel',np.float32,3),
('SuhaloLen',np.int32,1),
('M_Crit200',np.float32,1),
('R_Crit200',np.float32,1),
('Vvir',np.float32,1),
('Vmax',np.float32,1),
('HaloSpin',np.float32,3),    
('InfallVmax',np.float32,1),
('InfallVmaxPeak',np.float32,1),
('InfallSnap',np.int32,1),
('InfallHotGasMass',np.float32,1),
('HotGasRadius',np.float32,1),
('OriMergTime',np.float32,1),
('MergTime',np.float32,1),  
('ColdGasMass',np.float32,1),
('ColdGasMassRings',np.float32,12),
('H2fraction',np.float32,1), 
('H2fractionRings',np.float32,12),              
('StellarMass',np.float32,1),
('StellarDiskMass',np.float32,1),
('StellarBulgeMass',np.float32,1),
('StellarDiskMassRings',np.float32,12),   
('StellarBulgeMassRings',np.float32,12),   
('HotGasMass',np.float32,1),
('EjectedMass',np.float32,1),
('BlackHoleMass',np.float32,1),
('HaloStellarMass',np.float32,1),
('StellarMassFromInSitu',np.float32,1),
('StellarMassFromMergers',np.float32,1),
('StellarMassFromBursts',np.float32,1),
('MetalsColdGasMass',np.float32,3),
('MetalsColdGasMassRings',np.float32,[12,3]),
('MetalsStellarMass',np.float32,3),
('MetalsStellarDiskMass',np.float32,3),
('MetalsStellarBulgeMass',np.float32,3),
('MetalsStellarDiskMassRings',np.float32,[12,3]),  
('MetalsStellarBulgeMassRings',np.float32,[12,3]),  
('MetalsHotGasMass',np.float32,3),
('MetalsEjectedMass',np.float32,3),
('MetalsHaloStellarMass',np.float32,3), 
('PrimordialAccretionRate',np.float32,1),
('CoolingRadius',np.float32,1),
('CoolingRate',np.float32,1),
('CoolingRate_beforeAGN',np.float32,1),
('QuasarAccretionRate',np.float32,1),
('RadioAccretionRate',np.float32,1),
('StarFormationRate',np.float32,1),
('StarFormationRateRings',np.float32,12),        
('StarFormationRateBulge',np.float32,1),
('XrayLum',np.float32,1),
('BulgeSize',np.float32,1),
('StellarDiskRadius',np.float32,1),
('GasDiskRadius',np.float32,1),
('StellarHalfMassRadius',np.float32,1),  
('StellarHalfLightRadius',np.float32,1),           
('CosInclination',np.float32,1),
('DisruptOn',np.int32,1),
('MergeOn',np.int32,1), 
('MagDust',np.float32,20),
('Mag',np.float32,20),
('MagBulge',np.float32,20),
('MassWeightAge',np.float32,1),
('rBandWeightAge',np.float32,1),
('sfh_ibin',np.int32,1),      
('sfh_numbins',np.int32,1),        
('sfh_DiskMass',np.float32,20),
('sfh_BulgeMass',np.float32,20),
('sfh_DiskMassRings',np.float32,[12,20]),
('sfh_BulgeMassRings',np.float32,[12,20]),
('sfh_ICM',np.float32,20),
('sfh_MetalsDiskMass',np.float32,[20,3]),
('sfh_MetalsBulgeMass',np.float32,[20,3]),
('sfh_MetalsICM',np.float32,[20,3]),      
('sfh_ElementsDiskMass',np.float32,[20,11]),
('sfh_ElementsBulgeMass',np.float32,[20,11]),
('sfh_ElementsICM',np.float32,[20,11]),
('DiskMass_elements',np.float32,11),
('BulgeMass_elements',np.float32,11),
('DiskMassRings_elements',np.float32,[12,11]),        
('BulgeMassRings_elements',np.float32,[12,11]),    
('ColdGas_elements',np.float32,11),
('ColdGasRings_elements',np.float32,[12,11]),        
('HotGas_elements',np.float32,11),
('ICM_elements',np.float32,11),
('EjectedMass_elements',np.float32,11),
('rho_LBE_Gas',np.float32,1),
('VelRel_LBE',np.float32,1),
('StripFrac',np.float32,1),
('StrippedReservoirHotCen',np.float32,1),
('StrippedReservoirEjectedCen',np.float32,1),
('StrippedReservoirHotSat',np.float32,1),
('StrippedReservoirEjectedSat',np.float32,1),
('StrippedHotCen',np.float32,1),
('totStrippedHotCen',np.float32,1),
('StrippedEjectedCen',np.float32,1),
('totStrippedEjectedCen',np.float32,1),
('StrippedHotSat',np.float32,1),
('totStrippedHotSat',np.float32,1),
('StrippedEjectedSat',np.float32,1),
('totStrippedEjectedSat',np.float32,1),
('r_s_o',np.float32,1),
('np_bg',np.int32,1),
('Frac',np.float32,1),
('veldisp_sub',np.float32,1),
('veldisp_bg',np.float32,1),
('SplashFOFSnap1',np.int32,1),
('SplashVirSnap1',np.int32,1),
('SplashFOFSnap2',np.int32,1),
('SplashVirSnap2',np.int32,1),
('Mvir_original',np.float32,1),
('LenMax',np.int32,1),
('VelSubtoCen',np.float32,3),
('VelRelVec',np.float32,3),
('Vel_LBE',np.float32,3),
('SubhaloRadius',np.float32,1),
('HalfmassRad',np.float32,1),
('rho_LBE_Total',np.float32,1),
('rhoBG_oldcosmo',np.float32,1),
('R_rp',np.float32,1),
('Halo_BaryonMass',np.float32,1),
('MvirMax',np.float32,1)
])





PropertiesToRead = {}
for ii in LGalaxiesStruct.names:
	PropertiesToRead[ii] = False
           
PropertiesToRead['SnapNum'] = True
PropertiesToRead['ColdGasMassRings'] = True
PropertiesToRead['H2fractionRings'] = True
PropertiesToRead['StellarDiskMassRings'] = True
PropertiesToRead['StellarBulgeMassRings'] = True
PropertiesToRead['StellarMassFromInSitu'] = True
PropertiesToRead['StellarMassFromMergers'] = True
PropertiesToRead['StellarMassFromBursts'] = True
PropertiesToRead['MetalsColdGasMass'] = True
PropertiesToRead['MetalsColdGasMassRings'] = True
PropertiesToRead['MetalsStellarMass'] = True
PropertiesToRead['MetalsStellarDiskMass'] = True
PropertiesToRead['MetalsStellarBulgeMass'] = True
PropertiesToRead['MetalsStellarDiskMassRings'] = True
PropertiesToRead['MetalsStellarBulgeMassRings'] = True
PropertiesToRead['MetalsHotGasMass'] = True
PropertiesToRead['MetalsEjectedMass'] = True
PropertiesToRead['MetalsHaloStellarMass'] = True
PropertiesToRead['StarFormationRateRings'] = True
PropertiesToRead['DiskMass_elements'] = True
PropertiesToRead['BulgeMass_elements'] = True
PropertiesToRead['DiskMassRings_elements'] = True
PropertiesToRead['BulgeMassRings_elements'] = True
PropertiesToRead['ColdGas_elements'] = True
PropertiesToRead['ColdGasRings_elements'] = True
PropertiesToRead['HotGas_elements'] = True
PropertiesToRead['ICM_elements'] = True
PropertiesToRead['EjectedMass_elements'] = True